pub struct FullnodeClient { /* private fields */ }Expand description
A client for executing and simulating transactions via the full node gRPC service.
Implementations
Sourceimpl FullnodeClient
impl FullnodeClient
pub async fn new( prefix: Option<&str>, args: FullnodeArgs, registry: &Registry, ) -> Result<Option<Self>, Error>
pub fn as_data_loader(&self) -> DataLoader<Self>
Sourcepub async fn execute_transaction(
&self,
transaction_data: TransactionData,
signatures: Vec<GenericSignature>,
read_mask: FieldMask,
) -> Result<ExecuteTransactionResponse, Error>
pub async fn execute_transaction( &self, transaction_data: TransactionData, signatures: Vec<GenericSignature>, read_mask: FieldMask, ) -> Result<ExecuteTransactionResponse, Error>
Execute a transaction on the Sui network via gRPC.
Sourcepub async fn simulate_transaction(
&self,
transaction: Transaction,
checks_enabled: bool,
do_gas_selection: bool,
read_mask: FieldMask,
) -> Result<SimulateTransactionResponse, Error>
pub async fn simulate_transaction( &self, transaction: Transaction, checks_enabled: bool, do_gas_selection: bool, read_mask: FieldMask, ) -> Result<SimulateTransactionResponse, Error>
Simulate a transaction on the Sui network via gRPC. Note: Simulation does not require signatures since the transaction is not committed to the blockchain.
checks_enabled: If true, enables transaction validation checks during simulation.do_gas_selection: If true, enables automatic gas coin selection and budget estimation.
Sourcepub async fn calculate_rewards(
&self,
staked_sui_ids: &[Address],
) -> Result<Vec<u64>, Error>
pub async fn calculate_rewards( &self, staked_sui_ids: &[Address], ) -> Result<Vec<u64>, Error>
Construct and dry run PTBs to calculate the rewards for a list of staked SUI objects. Returns a list of u64 guaranteed to match the order of the input staked SUI ids.
Sourcepub async fn get_validator_address_by_pool_id(
&self,
pool_ids: &[Address],
) -> Result<Vec<Address>, Error>
pub async fn get_validator_address_by_pool_id( &self, pool_ids: &[Address], ) -> Result<Vec<Address>, Error>
Construct and dry run a PTB to get the corresponding validator addresses for a list of staking pool ids. Returns a list of validator addresses guaranteed to match the order of the input pool ids.